# py_carouselgreedy

**py_carouselgreedy** is a Python library designed to implement the *Carousel Greedy Algorithm*.  
Its goal is to provide a simple, modular, and efficient implementation of the algorithm, useful for combinatorial optimization problems.

Currently, the package is in an initial stage and will be expanded with additional features in the future.
